Class: Azure::CDN::Mgmt::V2020_09_01::Models::ResponseBasedOriginErrorDetectionParameters

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2020-09-01/generated/azure_mgmt_cdn/models/response_based_origin_error_detection_parameters.rb

Overview

The JSON object that contains the properties to determine origin health using real requests/responses.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#http_error_rangesArray<HttpErrorRangeParameters>

ranges that are considered as server errors for origin and it is marked as unhealthy.

Returns:



28
29
30
# File 'lib/2020-09-01/generated/azure_mgmt_cdn/models/response_based_origin_error_detection_parameters.rb', line 28

def http_error_ranges
  @http_error_ranges
end

#response_based_detected_error_typesResponseBasedDetectedErrorTypes

real user requests for which origin will be deemed unhealthy. Possible values include: ‘None’, ‘TcpErrorsOnly’, ‘TcpAndHttpErrors’

Returns:



19
20
21
# File 'lib/2020-09-01/generated/azure_mgmt_cdn/models/response_based_origin_error_detection_parameters.rb', line 19

def response_based_detected_error_types
  @response_based_detected_error_types
end

#response_based_failover_threshold_percentageInteger

failover should trigger.

Returns:

  • (Integer)

    The percentage of failed requests in the sample where



23
24
25
# File 'lib/2020-09-01/generated/azure_mgmt_cdn/models/response_based_origin_error_detection_parameters.rb', line 23

def response_based_failover_threshold_percentage
  @response_based_failover_threshold_percentage
end

Class Method Details

.mapperObject

Mapper for ResponseBasedOriginErrorDetectionParameters class as Ruby Hash. This will be used for serialization/deserialization.



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/2020-09-01/generated/azure_mgmt_cdn/models/response_based_origin_error_detection_parameters.rb', line 36

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'ResponseBasedOriginErrorDetectionParameters',
    type: {
      name: 'Composite',
      class_name: 'ResponseBasedOriginErrorDetectionParameters',
      model_properties: {
        response_based_detected_error_types: {
          client_side_validation: true,
          required: false,
          serialized_name: 'responseBasedDetectedErrorTypes',
          type: {
            name: 'Enum',
            module: 'ResponseBasedDetectedErrorTypes'
          }
        },
        response_based_failover_threshold_percentage: {
          client_side_validation: true,
          required: false,
          serialized_name: 'responseBasedFailoverThresholdPercentage',
          constraints: {
            InclusiveMaximum: 100,
            InclusiveMinimum: 0
          },
          type: {
            name: 'Number'
          }
        },
        http_error_ranges: {
          client_side_validation: true,
          required: false,
          serialized_name: 'httpErrorRanges',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'HttpErrorRangeParametersElementType',
                type: {
                  name: 'Composite',
                  class_name: 'HttpErrorRangeParameters'
                }
            }
          }
        }
      }
    }
  }
end